#version 110

#ifdef GL_ES
precision mediump float;
#endif

uniform vec3      iResolution;           // viewport resolution (in pixels)
uniform float     iDuration;             // shader playback total time (in seconds)
uniform float     iTime;                 // shader playback current time (in seconds)
uniform float     iTimeDelta;            // render time (in seconds)
uniform int       iFrame;                // shader playback frame
uniform float     iChannelTime[8];       // channel playback time (in seconds)
uniform vec3      iChannelResolution[8]; // channel resolution (in pixels)
uniform vec4      iMouse;                // mouse pixel coords. xy: current (if MLB down), zw: click
uniform sampler2D iChannel[8];           // input channel. XX = 2D/Cube
uniform vec4      iDate;                 // (year, month, day, time in seconds)
uniform float     iSampleRate;           // sound sample rate (i.e., 44100)

uniform float     strength;


float iProgress = iTime / iDuration;

const float PI = 3.141592653589793;

////////////////////////////////////////////////////////////////////////////////////////////////////////////

#define QUALITY 8

float size = 0.6;
 
const float GOLDEN_ANGLE = 2.399963229728653; // PI * (3.0 - sqrt(5.0))
 
vec4 blur(int fromorto, vec2 c, float radius) {
  vec4 sum = vec4(0.0);
  float q = float(QUALITY);
  // Using a "spiral" to propagate points.
  for (int i=0; i<QUALITY; ++i) {
    float fi = float(i);
    float a = fi * GOLDEN_ANGLE;
    float r = sqrt(fi / q) * radius;
    vec2 p = c + r * vec2(cos(a), sin(a));
	if(0 == fromorto)
	{
		sum += texture2D(iChannel[0], p);
	}
	
	if(1 == fromorto)
	{
		sum += texture2D(iChannel[1], p);
	}
  }
  return sum / q;
}
 
void mainImage( out vec4 fragColor, in vec2 fragCoord ) {
  vec2 p = fragCoord / iResolution.xy;
  float inv = 1.-iProgress;
  fragColor = inv*blur(0, p, iProgress*size) + iProgress*blur(1, p, inv*size);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////

void main() {
    mainImage(gl_FragColor, gl_FragCoord.xy);
}
